#
# spec file for package unibilium
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sover 4
Name:           unibilium
Version:        2.1.2
Release:        1.1
Summary:        A terminfo parsing library
License:        LGPL-3.0-or-later
Group:          Development/Libraries/C and C++
URL:            https://github.com/neovim/neovim/wiki/Deps#forks
Source:         https://github.com/neovim/unibilium/archive/v%{version}/unibilium-%{version}.tar.gz
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  libtool
BuildRequires:  pkgconfig

%description
Unibilium is a very basic terminfo library. It doesn't depend on curses or any
other library. It also doesn't use global variables, so it should be
thread-safe.

%package -n lib%{name}%{sover}
Summary:        A terminfo parsing library
Group:          System/Libraries

%description -n lib%{name}%{sover}
Unibilium is a very basic terminfo library. It doesn't depend on curses or any
other library. It also doesn't use global variables, so it should be
thread-safe.

This package holds the shared library.

%package devel
Summary:        Development files for unibilium, a terminfo parsing library
Group:          Development/Libraries/C and C++
Requires:       lib%{name}%{sover} = %{version}

%description devel
Unibilium is a very basic terminfo library. It doesn't depend on curses or any
other library. It also doesn't use global variables, so it should be
thread-safe.

This package holds the development files.

%prep
%autosetup

%build
autoreconf -vfi
%configure
%make_build

%install
%make_install

# Remove libtool files.
find %{buildroot} -type f -name "*.la" -delete -print

# Remove static library file.
rm -vf %{buildroot}%{_libdir}/lib%{name}.a

%ldconfig_scriptlets -n lib%{name}%{sover}

%files -n lib%{name}%{sover}
%license LICENSE
%doc Changes GPLv3 LGPLv3 README.md
%{_libdir}/lib%{name}.so.*

%files devel
%license LICENSE
%doc Changes GPLv3 LGPLv3 README.md
%{_includedir}/%{name}.h
%{_libdir}/lib%{name}.so
%{_libdir}/pkgconfig/%{name}.pc
%{_mandir}/man?/unibi*.?%{?ext_man}

%changelog
* Wed Mar 26 2025 Richard Rahl <rrahl0@opensuse.org>
- update to 2.1.2:
  * build: Add a minimal configure.ac
  * build: bump minimum required cmake
  * build(cmake): allow user to set TERMINFO_DIRS
  * Do not stop searching on EPERM
- use newer macros (autosetup, ldconfig_scriptlets, make)
* Thu Jul  1 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to 2.1.1
  * Only build system related changes
* Fri Sep 11 2020 Dirk Mueller <dmueller@suse.com>
- update to 2.1.0:
  - Makefile: use "-f" with prove always (to show failed tests) (#13)
  - Stop searching in further dirs on errors except ENOENT #12
  - Makefile: do not rebuild t/static_%%.c with updated gen-static-test
  - Add CMakeLists.txt and support for MSVC (#3)
  - Relax checks for extended capability to support new format (#5)
  - Makefile: use -Og with DEBUG=1 (#7)
  - unibi_from_mem: fix [clang-analyzer-deadcode.DeadStores] (#8)
  - Makefile: revisit regenerate-tests rule (#6)
  - unibi_from_term: handle $TERMINFO as curses does #2
* Tue Mar 27 2018 jengelh@inai.de
- Fix SRPM group. Update summaries. Use %%make_install macro.
* Mon Mar 26 2018 ronisbr@gmail.com
- Run spec-cleaner.
- Version bump to 2.0.0.
  Upstream changelog:
  Version 2.0.0
  - ------------
  - rewrite unibi_var_t internals (now the only official access is
    via the helper functions)
  - numeric capabilities are stored as ints now (used to be shorts)
  - add support for the ncurses 6.1 "wide integer" 32-bit file
    format
  - try ncursesw6-config, ncurses6-config, ncursesw5-config, and
    ncurses5-config to get the list of terminfo directories
    (TERMINFO_DIRS) when building
  - improve README.md with build instructions and prerequisites
  Version 1.2.1
  - ------------
  - deprecate direct access to unibi_var_t members
  - better support for building on Windows
* Fri Dec 11 2015 ronisbr@gmail.com
- Change package name to unibilium as per DimStar request.
* Sat Dec  5 2015 ronisbr@gmail.com
- Change %%{soname} to %%{sover}.
* Sat Dec  5 2015 ronisbr@gmail.com
- Fix group for libunibilium and libunibilium0 packages.
* Sat Dec  5 2015 ronisbr@gmail.com
- Remove libtool files.
* Sat Dec  5 2015 ronisbr@gmail.com
- Change package name to libunibilium.
* Wed Dec  2 2015 ronisbr@gmail.com
- Version bump to 1.2.0.
- Clean spec file.
* Fri Apr 17 2015 mrueckert@suse.de
- initial package
